// File:    helpdemo.prg
// Purpose: Implementation of online help using Alaska Software Xbase++
// Date:    2012.10.02
//

#include  "appevent.ch"


// function main - application entry
// syntax:  main() --> nil
//
function main()
local nEvent, mp1, mp2, oXbp
local oDlg

oDlg := createMainDialog()                  // create application main dialog
createMenu(oDlg)                            // create menu system
setAppWindow(oDlg)                          // set as application window
setAppFocus(oDlg)

helpObject("help\sample.chm", "Xbase++ help sample") // create help file container
oDlg:helpLink := helpLink()                 // create link to default page

do while .t.
  nEvent := appEvent(@mp1, @mp2, @oXbp)

  if nEvent = xbeP_Close
    if oXbp = oDlg                          // quit on main dialog
      exit
    else                                    // quit on child dialog
      oXbp:destroy()
    endif

  else                                      // other events
    oXbp:handleEvent(nEvent, mp1, mp2)
  endif
enddo
oDlg:destroy()
return nil
// eof main


// function createMainDialog - create the application main dialog
// syntax:  createMainDialog() --> oDlg
//
function createMainDialog()
local oDlg

oDlg  := xbpDialog():new(appDesktop(),, {100, 100}, {500, 500})
oDlg:taskList := .t.
oDlg:title    := "Demo implementation online help"
oDlg:create()
//oDlg:drawingarea:setFont(xbpFont():new():create(XBPSYSFNT_GUIDEFAULT))
return oDlg
// eof createMainDialog


// function createChildDialog - create an MDI dialog
// syntax:  createChildDialog(oParent, [aPos], [aSize], [cTitle]) --> oDlg
//
function createChildDialog(oParent, aPos, aSize, cTitle)
local oDlg, aParent, oStatic, oGet, oBtn

oParent := isNull(oParent, setAppWindow())
aParent := oParent:drawingArea:currentSize()
aPos    := isNull(aPos,  {0.2* aParent[1], 0.1* aParent[2]})
aSize   := isNull(aSize, {min(300, 0.6* aParent[1]), min(300, 0.8* aParent[2])})

oDlg  := xbpDialog():new(oParent:drawingArea,, aPos, aSize)
oDlg:title     := isNull(cTitle, "Child window")
oDlg:helpLink  := helpLink("child_dialog.htm")
oDlg:create()

aSize   := oDlg:drawingArea:currentSize()   // update available space
// create a static to place the gets on
oStatic := xbpStatic():new(oDlg:drawingArea,, {0,0}, aSize)
oStatic:create()

// create two gets with context sensitive help
oGet    := xbpSle():new(oStatic,, {020, 155}, {aSize[1]- 040, 022}):create()
oGet:helpLink  := helpLink("first_get.htm")
oGet:cueBanner := "Context sensitive"
oGet:tabStop   := .t.

oGet    := xbpSle():new(oStatic,, {020, 125}, {aSize[1]- 040, 022}):create()
oGet:helpLink  := helpLink("second_get.htm")
oGet:cueBanner := "Context sensitive here too"
oGet:tabStop   := .t.

// create another get without help link
// the help should now default to the help page for the child dialog
oGet    := xbpSle():new(oStatic,, {020, 095}, {aSize[1]- 040, 022}):create()
oGet:cueBanner := "No context sensitive help"
oGet:tabStop   := .t.

// create a pushbutton that displays a specific help page
oBtn    := xbpPushButton():new(oStatic,, {020, 020}, {aSize[1]- 040, 030})
oBtn:caption   := "Push for help"
oBtn:tabStop   := .t.
oBtn:activate  := {|| helpLink("pushbutton.htm"):showHelpLink() }
oBtn:create()

setAppFocus(oDlg)                           // set focus to this dialog
return oDlg
// eof createChildDialog


// function createMenu - create the application menu
// syntax:  createMenu(oMainDlg) --> oMenu
//
function createMenu(oDlg)
local oMenuBar, oMenu

oMenuBar := oDlg:menuBar()

oMenu := xbpMenu():new(oMenuBar):create()
oMenu:title := "Dialog"
oMenu:addItem({"MDI child",     {|| createChildDialog() }})
oMenuBar:addItem({oMenu, nil})

oMenu := xbpMenu():new(oMenuBar):create()
oMenu:title := "Help"
oMenu:addItem({"Online help",   {|| helpObject():showHelp("introduction.htm") }})
oMenuBar:addItem({oMenu, nil})
return nil
// eof createMenu


// function helpObject - create container for help file
// syntax:  helpObject([cHelpFile], [cDialogTitle]) --> oHelpObject
//
function helpObject(cHelpFile, cTitle)
static soHelp

if cHelpFile # nil .and. ;                  // help file specified
    soHelp = nil                            // help not yet initialised
  soHelp := xbpHelp():new()
  soHelp:create(setAppWindow(), cHelpFile, cTitle)
endif
return soHelp
// eof helpObject


// function helpLink - create reference to page in help file
// syntax:  helpLink([cHelpPage], [cHelpFile], [cDialogTitle]) --> oLink
// remark:  when the help page parameter is omitted
//          the default page of the help file is displayed
//
function helpLink(cHelpPage, cHelpFile, cTitle)
local oLink

oLink := xbpHelpLabel():new():create(cHelpPage)

if cHelpFile = nil                          // default help file
  oLink:helpObject := helpObject()

else                                        // non-default help file
  oLink:helpObject := xbpHelp():new():create(, cHelpFile, cTitle)
endif
return oLink
// eof helpLink


// function appSys - application startup routine
// syntax:  appSys() --> nil
//
function appSys()
// we're not doing anything here
return nil
// eof appSys


// function dbeSys - load database drivers
// syntax:  dbeSys() --> nil
//
function dbeSys()
// not applicable for this sample
return nil
// eof dbeSys
